@@ -323,7 +323,7 @@ gda_field_get_value (GdaField *field)
  * gda_field_set_value
  */
 void
-gda_field_set_value (GdaField *field, GdaValue *value)
+gda_field_set_value (GdaField *field, const GdaValue *value)
 {
 	g_return_if_fail (field != NULL);
 	g_return_if_fail (value != NULL);
@@ -452,6 +452,31 @@ gda_field_set_double_value (GdaField *field, gdouble value)
 	gda_value_set_double (&field->value, value);
 }
 
+/**
+ * gda_field_get_geometric_point_value
+ */
+GdaGeometricPoint *
+gda_field_get_geometric_point_value (GdaField *field)
+{
+	g_return_val_if_fail (field != NULL, NULL);
+	return gda_value_get_geometric_point (&field->value);
+}
+
+/**
+ * gda_field_set_geometric_point_value
+ */
+void
+gda_field_set_geometric_point_value (GdaField *field, GdaGeometricPoint *value)
+{
+	g_return_if_fail (field != NULL);
+	g_return_if_fail (value != NULL);
+
+	field->attributes.gdaType = GDA_TYPE_GEOMETRIC_POINT;
+	field->actualSize = sizeof (GdaGeometricPoint);
+
+	gda_value_set_geometric_point (&field->value, value);
+}
+
 /**
  * gda_field_get_integer_value
  */
@@ -631,8 +656,6 @@ gda_field_set_tinyint_value (GdaField *field, gchar value)
 	gda_value_set_tinyint (&field->value, value);
 }
 
-
-
 /**
  * gda_field_stringify
  */
